@@ -191,7 +191,6 @@ GSList *
 gdm_config_get_xservers (gboolean flexible)
 {
 	GSList *xservers = NULL;
-	gchar *p;
         gchar **splitstr, **sec;
 	gchar *command = NULL;
 	gchar *result  = NULL;
@@ -214,13 +213,12 @@ gdm_config_get_xservers (gboolean flexible)
 	}
 
 	/* skip the "OK " */
-	splitstr = g_strsplit (result + 3, ";", 0);
-	sec      = splitstr;
+        splitstr = g_strsplit (result + 3, ";", 0);
+	sec = splitstr;
 	g_free (result);
 
-	while (sec != NULL && *sec != NULL) {
+        while (*sec != NULL) {
 		GdmXserver *svr = g_new0 (GdmXserver, 1);
-		gchar *temp;
 
 		temp = gdm_config_get_xserver_details (*sec, "ID");
 		if (temp == NULL) {
@@ -528,7 +526,7 @@ gdm_config_get_int (gchar *key)
  * socket command.  It stores the value in a hash so subsequent
  * access is faster.
  */
-static gboolean
+gboolean
 _gdm_config_get_bool (gchar *key, gboolean reload, gboolean *changed)
 {
 	gboolean *hashretval = NULL;
@@ -629,7 +627,7 @@ gdm_config_reload_string (gchar *key)
 	return changed;
 }
 
-static gboolean
+gboolean
 gdm_config_reload_translated_string (gchar *key)
 {
 	gboolean changed;
