@@ -28,8 +28,6 @@
 #include "greeter_configuration.h"
 #include "greeter_system.h"
 #include "greeter_item.h"
-#include "greeter_item_ulist.h"
-#include "greeter_parser.h"
 #include "gdm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
@@ -78,6 +76,7 @@ query_greeter_restart_handler (void)
 	}
 }
 
+
 static void
 query_greeter_halt_handler (void)
 {
@@ -125,7 +124,7 @@ greeter_suspend_handler (void)
 static void
 greeter_config_handler (void)
 {
-	greeter_item_ulist_disable ();
+        greeter_item_ulist_disable ();
 
 	/* Make sure to unselect the user */
 	greeter_item_ulist_unset_selected_user ();
